@@ -185,7 +185,7 @@ static struct i2c_driver lm78_driver = {
 #define LM78_SYSCTL_FAN1 1101	/* Rotations/min */
 #define LM78_SYSCTL_FAN2 1102
 #define LM78_SYSCTL_FAN3 1103
-#define LM78_SYSCTL_TEMP 1200	/* Degrees Celcius * 10 */
+#define LM78_SYSCTL_TEMP 1200	/* Degrees Celsius * 10 */
 #define LM78_SYSCTL_VID 1300	/* Volts * 100 */
 #define LM78_SYSCTL_FAN_DIV 2000	/* 1, 2, 4 or 8 */
 #define LM78_SYSCTL_ALARMS 2001	/* bitvector */
@@ -430,7 +430,7 @@ static int lm78_detach_client(struct i2c_client *client)
 	return 0;
 }
 
-/* The SMBus locks itself, but ISA access must be locked explicitely! 
+/* The SMBus locks itself, but ISA access must be locked explicitly! 
    We don't want to lock the whole ISA bus, so we lock each client
    separately.
    We ignore the LM78 BUSY flag at this moment - it could lead to deadlocks,
@@ -450,7 +450,7 @@ static int lm78_read_value(struct i2c_client *client, u8 reg)
 		return i2c_smbus_read_byte_data(client, reg);
 }
 
-/* The SMBus locks itself, but ISA access muse be locked explicitely! 
+/* The SMBus locks itself, but ISA access muse be locked explicitly! 
    We don't want to lock the whole ISA bus, so we lock each client
    separately.
    We ignore the LM78 BUSY flag at this moment - it could lead to deadlocks,
