@@ -272,9 +272,9 @@ static struct i2c_driver mtp008_driver =
 #define MTP008_SYSCTL_FAN1	1101	/* Rotations/min */
 #define MTP008_SYSCTL_FAN2	1102
 #define MTP008_SYSCTL_FAN3	1103
-#define MTP008_SYSCTL_TEMP1	1200	/* Degrees Celcius * 10 */
-#define MTP008_SYSCTL_TEMP2	1201	/* Degrees Celcius * 10 */
-#define MTP008_SYSCTL_TEMP3	1202	/* Degrees Celcius * 10 */
+#define MTP008_SYSCTL_TEMP1	1200	/* Degrees Celsius * 10 */
+#define MTP008_SYSCTL_TEMP2	1201	/* Degrees Celsius * 10 */
+#define MTP008_SYSCTL_TEMP3	1202	/* Degrees Celsius * 10 */
 #define MTP008_SYSCTL_VID	1300	/* Volts * 100 */
 #define MTP008_SYSCTL_PWM1	1401
 #define MTP008_SYSCTL_PWM2	1402
