@@ -1,7 +1,8 @@
 #!/usr/bin/perl
 
 #    mkpatch - Create patches against the Linux kernel
-#    Copyright (c) 1999  Frodo Looijaard <frodol@dds.nl>
+#    Copyright (C) 1999  Frodo Looijaard <frodol@dds.nl>
+#    Copyright (C) 2005  Jean Delvare <khali@linux-fr.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -82,7 +83,9 @@ sub gen_Documentation_Configure_help
     if (m@I2C mainboard interfaces@ or
            m@Acer Labs ALI 1535@ or
            m@Acer Labs ALI 1533 and 1543C@ or
+           m@Acer Labs ALI 1563@ or
            m@AMD 756/766/768/8111@ or
+           m@SMBus multiplexing on the Tyan S4882@ or
            m@AMD 8111 SMBus 2.0@ or
            m@Apple Hydra Mac I/O@ or
            m@Intel I801@ or
@@ -99,9 +102,11 @@ sub gen_Documentation_Configure_help
            m@Analog Devices ADM1024@ or
            m@Analog Devices ADM1025@ or
            m@Analog Devices ADM1026@ or
+           m@Analog Devices ADM1030, ADM1031@ or
            m@Analog Devices ADM9240 and compatibles@ or
            m@Asus ASB100@ or
            m@Dallas DS1621 and DS1625@ or
+           m@Fujitsu-Siemens Hermes@ or
            m@Fujitsu-Siemens Poseidon@ or
            m@Fujitsu-Siemens Scylla@ or
            m@Genesys Logic GL518SM@ or
@@ -109,8 +114,10 @@ sub gen_Documentation_Configure_help
            m@HP Maxilife@ or
            m@Intel Xeon Thermal Sensor@ or
            m@ITE 8705, 8712, Sis950@ or
+           m@Maxim MAX1619@ or
            m@Maxim MAX6650, MAX6651@ or
            m@Myson MTP008@ or
+           m@National Semiconductor LM63@ or
            m@National Semiconductor LM75 and compatibles@ or
            m@National Semiconductor LM78@ or
            m@National Semiconductor LM80@ or
@@ -119,12 +126,14 @@ sub gen_Documentation_Configure_help
            m@National Semiconductor LM87@ or
            m@National Semiconductor LM90@ or
            m@National Semiconductor LM92@ or
+           m@National Semiconductor LM93@ or
            m@National Semiconductor PC8736x@ or
            m@Silicon Integrated Systems Corp. SiS5595 Sensor@ or
            m@Texas Instruments THMC50 / Analog Devices ADM1022@ or
            m@Via VT82C686A/B@ or
-           m@Winbond W83781D, W83782D, W83783S, W83627HF, AS99127F@ or
-           m@Winbond W83627HF, W83627THF, W83697HF@ or
+           m@Winbond W83781D, W83782D, W83783S@ or
+           m@Winbond W83792D@ or
+           m@Winbond W83627HF, W83627THF@ or
            m@Winbond W83L785TS-S@ or
            m@EEprom \(DIMM\) reader@) {
       $_ = <INPUT>;
@@ -158,12 +167,26 @@ CONFIG_I2C_ALI15X3
   built as a module which can be inserted and removed while the kernel
   is running.
 
-AMD 756/766/768/8111
+Acer Labs ALI 1563
+CONFIG_I2C_ALI1563
+  If you say yes to this option, support will be included for the Acer
+  Labs ALI M1563 mainboard SMBus interface. This can also be built as a
+  module.
+
+AMD 756/766/768/8111 and nVidia nForce
 CONFIG_I2C_AMD756
   If you say yes to this option, support will be included for the AMD
-  756/766/768/8111 mainboard I2C interfaces. This can also be 
-  built as a module which can be inserted and removed while the kernel
-  is running.
+  756/766/768/8111 and nVidia nForce mainboard I2C interfaces. This can
+  also be built as a module which can be inserted and removed while the
+  kernel is running.
+
+SMBus multiplexing on the Tyan S4882
+CONFIG_I2C_AMD756_S4882
+  Enabling this option will add specific SMBus support for the Tyan
+  S4882 motherboard. On this 4-CPU board, the SMBus is multiplexed
+  over 8 different channels, where the various memory module EEPROMs
+  and temperature sensors live. Saying yes here will give you access
+  to these in addition to the trunk.
 
 AMD 8111 SMBus 2.0
 CONFIG_I2C_AMD8111
@@ -204,12 +227,12 @@ CONFIG_I2C_PIIX4
   built as a module which can be inserted and removed while the kernel
   is running.
 
-Nvidia Nforce2 based Mainboard
+Nvidia Nforce2/Nforce3 based Mainboard
 CONFIG_I2C_NFORCE2
   If you say yes to this option, support will be included for the 
-  Nvidia Nforce2 family of mainboard I2C interfaces. This can also be
-  built as a module which can be inserted and removed while the kernel
-  is running.
+  Nvidia Nforce2 and Nforce3 families of mainboard I2C interfaces.
+  This can also be built as a module which can be inserted and removed
+  while the kernel is running.
 
 Silicon Integrated Systems Corp. SiS5595 based Mainboard
 CONFIG_I2C_SIS5595
@@ -314,6 +337,16 @@ CONFIG_SENSORS_ADM1026
   in the lm_sensors package, which you can download at 
   http://www.lm-sensors.nu
 
+Analog Devices ADM1030, ADM1031
+CONFIG_SENSORS_ADM1031
+  If you say yes here you get support for Analog Devices ADM1030 and
+  ADM1031 sensor chips.  This can also be built as a module which can
+  be inserted and removed while the kernel is running.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
 Analog Devices ADM9240 and compatibles
 CONFIG_SENSORS_ADM9240
   If you say yes here you get support for Analog Devices ADM9240 
@@ -344,6 +377,15 @@ CONFIG_SENSORS_DS1621
   in the lm_sensors package, which you can download at 
   http://www.lm-sensors.nu
 
+Fujitsu-Siemens Hermes
+CONFIG_SENSORS_FSCHER
+  If you say yes here you get support for the Fujitsu-Siemens Hermes
+  sensor chip.  This can also be built as a module.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
 Fujitsu-Siemens Poseidon
 CONFIG_SENSORS_FSCPOS
   If you say yes here you get support for the Fujitsu-Siemens Poseidon
@@ -414,6 +456,15 @@ CONFIG_SENSORS_IT87
   in the lm_sensors package, which you can download at 
   http://www.lm-sensors.nu
 
+Maxim MAX1619
+CONFIG_SENSORS_MAX1619
+  If you say yes here you get support for the Maxim MAX1619 sensor
+  chips.  This can also be built as a module.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
 Maxim MAX6650, MAX6651
 CONFIG_SENSORS_MAX6650
   If you say yes here you get support for the Maxim MAX6650 and
@@ -432,6 +483,16 @@ CONFIG_SENSORS_MTP008
   in the lm_sensors package, which you can download at 
   http://www.lm-sensors.nu
 
+National Semiconductor LM63
+CONFIG_SENSORS_LM63
+  If you say yes here you get support for National Semiconductor LM63
+  sensor chips.  This can also be built as a module which can be inserted
+  and removed while the kernel is running.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
 National Semiconductor LM75 and compatibles
 CONFIG_SENSORS_LM75 
   If you say yes here you get support for National Semiconductor LM75
@@ -500,8 +561,8 @@ CONFIG_SENSORS_LM87
 National Semiconductor LM90
 CONFIG_SENSORS_LM90
   If you say yes here you get support for the National Semiconductor
-  LM90, LM89 and LM99, and Analog Devices ADM1032 sensor chips.  This
-  can also be built as a module.
+  LM90, LM89 and LM99, Analog Devices ADM1032 and ADT7461, and Maxim
+  MAX6657 and MAX6658 sensor chips.  This can also be built as a module.
 
   You will also need the latest user-space utilities: you can find
   them in the lm_sensors package, which you can download at
@@ -517,6 +578,16 @@ CONFIG_SENSORS_LM92
   in the lm_sensors package, which you can download at 
   http://www.lm-sensors.nu
 
+National Semiconductor LM93
+CONFIG_SENSORS_LM93
+  If you say yes here you get support for National Semiconductor LM93
+  sensor chips.  This can also be built as a module which can be inserted
+  and removed while the kernel is running.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
 National Semiconductor PC8736x Sensors
 CONFIG_SENSORS_PC87360
   If you say yes here you get support for the integrated hardware
@@ -615,21 +686,29 @@ CONFIG_SENSORS_VT8231
 
 Winbond W83781D, W83782D, W83783S, W83627HF, AS99127F
 CONFIG_SENSORS_W83781D
-  If you say yes here you get support for the Winbond W8378x series 
-  of sensor chips: the W83781D, W83782D, W83783S and W83682HF,
-  and the similar Asus AS99127F. This
-  can also be built as a module which can be inserted and removed
-  while the kernel is running.
+  If you say yes here you get support for the Winbond W8378x series
+  of sensor chips: the W83781D, W83782D, W83783S and W83627HF,
+  and the similar Asus AS99127F. This can also be built as a module
+  which can be inserted and removed while the kernel is running.
+
+  You will also need the latest user-space utilties: you can find them
+  in the lm_sensors package, which you can download at
+  http://www.lm-sensors.nu/
+
+Winbond W83792D
+CONFIG_SENSORS_W83792D
+  If you say yes here you get support for the Winbond W83792D
+  sensor chips.
 
   You will also need the latest user-space utilties: you can find them
   in the lm_sensors package, which you can download at 
-  http://www.lm-sensors.nu
+  http://www.lm-sensors.nu/
 
-Winbond W83627HF, W83627THF, W83697HF
+Winbond W83627HF, W83627THF, W83637HF, W83697HF
 CONFIG_SENSORS_W83627HF
-  If you say yes here you get support for the Winbond W836x7 series 
-  of sensor chips: the Winbond W83627HF, W83627THF and W83697HF. This
-  can also be built as a module which can be inserted and removed
+  If you say yes here you get support for the Winbond W836x7 series
+  of sensor chips: the W83627HF, W83627THF, W83637HF and W83697HF.
+  This can also be built as a module which can be inserted and removed
   while the kernel is running.
 
   You will also need the latest user-space utilities: you can find
@@ -874,8 +953,12 @@ sub gen_drivers_i2c_Config_in
   if [ "$CONFIG_I2C_MAINBOARD" = "y" ]; then
     dep_tristate '  Acer Labs ALI 1535' CONFIG_I2C_ALI1535 $CONFIG_I2C
     dep_tristate '  Acer Labs ALI 1533 and 1543C' CONFIG_I2C_ALI15X3 $CONFIG_I2C
+    dep_tristate '  Acer Labs ALI 1563' CONFIG_I2C_ALI1563 $CONFIG_I2C
     dep_tristate '  Apple Hydra Mac I/O' CONFIG_I2C_HYDRA $CONFIG_I2C_ALGOBIT
-    dep_tristate '  AMD 756/766/768/8111' CONFIG_I2C_AMD756 $CONFIG_I2C
+    dep_tristate '  AMD 756/766/768/8111 and nVidia nForce' CONFIG_I2C_AMD756 $CONFIG_I2C
+    if [ "$CONFIG_I2C_AMD756" != "n" ]; then
+      dep_tristate '    SMBus multiplexing on the Tyan S4882' CONFIG_I2C_AMD756_S4882 $CONFIG_I2C_AMD756
+    fi
     dep_tristate '  AMD 8111 SMBus 2.0' CONFIG_I2C_AMD8111 $CONFIG_I2C
     if [ "$CONFIG_ALPHA" = "y" ]; then
       dep_tristate '  DEC Tsunami I2C interface' CONFIG_I2C_TSUNAMI $CONFIG_I2C_ALGOBIT
@@ -883,7 +966,7 @@ sub gen_drivers_i2c_Config_in
     dep_tristate '  Intel 82801AA, AB, BA, DB' CONFIG_I2C_I801 $CONFIG_I2C
     dep_tristate '  Intel i810AA/AB/E and i815' CONFIG_I2C_I810 $CONFIG_I2C_ALGOBIT
     dep_tristate '  Intel 82371AB PIIX4(E), 443MX, ServerWorks OSB4/CSB5, SMSC Victory66' CONFIG_I2C_PIIX4 $CONFIG_I2C
-    dep_tristate '  Nvidia Nforce2' CONFIG_I2C_NFORCE2 $CONFIG_I2C
+    dep_tristate '  Nvidia Nforce2/Nforce3' CONFIG_I2C_NFORCE2 $CONFIG_I2C
     dep_tristate '  SiS 5595' CONFIG_I2C_SIS5595 $CONFIG_I2C
     dep_tristate '  SiS 630/730' CONFIG_I2C_SIS630 $CONFIG_I2C
     dep_tristate '  SiS 645/961,645DX/961,735' CONFIG_I2C_SIS645 $CONFIG_I2C $CONFIG_HOTPLUG
@@ -925,17 +1008,20 @@ obj-$(CONFIG_SENSORS_ADM1021)	+= adm1021.o
 obj-$(CONFIG_SENSORS_ADM1024)	+= adm1024.o
 obj-$(CONFIG_SENSORS_ADM1025)	+= adm1025.o
 obj-$(CONFIG_SENSORS_ADM1026)	+= adm1026.o
+obj-$(CONFIG_SENSORS_ADM1031)	+= adm1031.o
 obj-$(CONFIG_SENSORS_ADM9240)	+= adm9240.o
 obj-$(CONFIG_SENSORS_ASB100)	+= asb100.o
 obj-$(CONFIG_SENSORS_BT869)	+= bt869.o
 obj-$(CONFIG_SENSORS_DDCMON)	+= ddcmon.o
 obj-$(CONFIG_SENSORS_DS1621)	+= ds1621.o
 obj-$(CONFIG_SENSORS_EEPROM)	+= eeprom.o
+obj-$(CONFIG_SENSORS_FSCHER)	+= fscher.o
 obj-$(CONFIG_SENSORS_FSCPOS)	+= fscpos.o
 obj-$(CONFIG_SENSORS_FSCSCY)	+= fscscy.o
 obj-$(CONFIG_SENSORS_GL518SM)	+= gl518sm.o
 obj-$(CONFIG_SENSORS_GL520SM)	+= gl520sm.o
 obj-$(CONFIG_SENSORS_IT87)	+= it87.o
+obj-$(CONFIG_SENSORS_LM63)	+= lm63.o
 obj-$(CONFIG_SENSORS_LM75)	+= lm75.o
 obj-$(CONFIG_SENSORS_LM78)	+= lm78.o
 obj-$(CONFIG_SENSORS_LM80)	+= lm80.o
@@ -944,6 +1030,8 @@ obj-$(CONFIG_SENSORS_LM85)	+= lm85.o
 obj-$(CONFIG_SENSORS_LM87)	+= lm87.o
 obj-$(CONFIG_SENSORS_LM90)	+= lm90.o
 obj-$(CONFIG_SENSORS_LM92)	+= lm92.o
+obj-$(CONFIG_SENSORS_LM93)	+= lm93.o
+obj-$(CONFIG_SENSORS_MAX1619)	+= max1619.o
 obj-$(CONFIG_SENSORS_MAX6650)	+= max6650.o
 obj-$(CONFIG_SENSORS_MAXILIFE)	+= maxilife.o
 obj-$(CONFIG_SENSORS_MTP008)	+= mtp008.o
@@ -957,6 +1045,7 @@ obj-$(CONFIG_SENSORS_VIA686A)	+= via686a.o
 obj-$(CONFIG_SENSORS_VT1211)	+= vt1211.o
 obj-$(CONFIG_SENSORS_VT8231)	+= vt8231.o
 obj-$(CONFIG_SENSORS_W83781D)	+= w83781d.o
+obj-$(CONFIG_SENSORS_W83792D)	+= w83792d.o
 obj-$(CONFIG_SENSORS_W83627HF)	+= w83627hf.o
 obj-$(CONFIG_SENSORS_W83L785TS)	+= w83l785ts.o
 obj-$(CONFIG_SENSORS_XEONTEMP)	+= xeontemp.o
@@ -993,9 +1082,13 @@ sub gen_drivers_i2c_Makefile
         last if m@sensors code ends here@;
       }
       print OUTPUT <<'EOF';
+export-objs	+= i2c-amd756.o
+
 obj-$(CONFIG_I2C_ALI1535)		+= i2c-ali1535.o
 obj-$(CONFIG_I2C_ALI15X3)		+= i2c-ali15x3.o
+obj-$(CONFIG_I2C_ALI1563)		+= i2c-ali1563.o
 obj-$(CONFIG_I2C_AMD756)		+= i2c-amd756.o
+obj-$(CONFIG_I2C_AMD756_S4882)		+= i2c-amd756-s4882.o
 obj-$(CONFIG_I2C_AMD8111)		+= i2c-amd8111.o
 obj-$(CONFIG_I2C_HYDRA)			+= i2c-hydra.o
 obj-$(CONFIG_I2C_I801)			+= i2c-i801.o
@@ -1045,11 +1138,7 @@ sub gen_MAINTAINERS
     if (not $done and (m@SGI VISUAL WORKSTATION 320 AND 540@)) {
       print OUTPUT <<'EOF';
 SENSORS DRIVERS
-P:      Frodo Looijaard
-M:      frodol@dds.nl
-P:      Philip Edelbrock
-M:      phil@netroedge.com
-L:      sensors@stimpy.netroedge.com
+L:      lm-sensors@lm-sensors.org
 W:      http://www.lm-sensors.nu/
 S:      Maintained
 
@@ -1219,6 +1308,9 @@ sub main
   gen_Documentation_Configure_help $package_root, $kernel_root;
   gen_MAINTAINERS $package_root, $kernel_root;
   gen_dmi_scan $package_root, $kernel_root;
+
+  # Clear temporary file
+  unlink("$package_root/$temp");
 }
 
 main;
