@@ -1,7 +1,8 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 #
 # Copyright 1998, 1999 Philip Edelbrock <phil@netroedge.com>
 # modified by Christian Zuckschwerdt <zany@triq.net>
+# modified by Burkart Lingner <burkart@bollchen.de>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -22,8 +23,20 @@
 #  html output (selectable by commandline switches)
 # Version 0.6  2000-09-16  Christian Zuckschwerdt <zany@triq.net>
 #  updated according to SPD Spec Rev 1.2B
-#  see http://developer.intel.com/
-#             technology/memory/pc133sdram/spec/Spdsd12b.htm
+#  see http://developer.intel.com/technology/memory/pc133sdram/spec/Spdsd12b.htm
+# Version 0.7  2002-11-08  Jean Delvare <khali@linux-fr.org>
+#  pass -w and use strict
+#  valid HTML 3.2 output (--format mode)
+#  miscellaneous formatting enhancements and bug fixes
+#  clearer HTML output (original patch by Nick Kurshev <nickols_k@mail.ru>)
+#  stop decoding on checksum error by default (--checksum option forces)
+# Version 0.8  2005-06-20  Burkart Lingner <burkart@bollchen.de>
+#  adapted to Kernel 2.6's /sys filesystem
+# Version 0.9  2005-07-15  Jean Delvare <khali@linux-fr.org>
+#  fix perl warning
+#  fix typo
+#  refactor some code
+#
 #
 # EEPROM data decoding for SDRAM DIMM modules. 
 #
@@ -32,8 +45,9 @@
 #
 # use the following command line switches
 #  -f, --format            print nice html output
-#  -b, --bodyonly          don't printhtml header
+#  -b, --bodyonly          don't print html header
 #                          (useful for postprocessing the output)
+#  -c, --checksum          decode completely even if checksum fails
 #  -h, --help              display this usage summary
 #
 # References: 
@@ -45,11 +59,21 @@
 # http://www.jedec.org
 #
 
+use strict;
+use vars qw($opt_html $opt_body $opt_bodyonly $opt_igncheck $use_sysfs);
+
+$use_sysfs = -d '/sys/bus';
+
 sub printl ($$) # print a line w/ label and value
 {
    my ($label, $value) = @_;
    if ($opt_html) {
-       $value =~ s%\n%<br>%sg;
+       $label =~ s/</\&lt;/sg;
+       $label =~ s/>/\&gt;/sg;
+       $label =~ s/\n/<br>\n/sg;
+       $value =~ s/</\&lt;/sg;
+       $value =~ s/>/\&gt;/sg;
+       $value =~ s/\n/<br>\n/sg;
        print "<tr><td valign=top>$label</td><td>$value</td></tr>\n";
    } else {
        $value =~ s%\n%\n\t\t%sg;
@@ -57,10 +81,30 @@ sub printl ($$) # print a line w/ label and value
    }
 }
 
+sub printl2 ($$) # print a line w/ label and value (outside a table)
+{
+   my ($label, $value) = @_;
+   if ($opt_html) {
+       $label =~ s/</\&lt;/sg;
+       $label =~ s/>/\&gt;/sg;
+       $label =~ s/\n/<br>\n/sg;
+       $value =~ s/</\&lt;/sg;
+       $value =~ s/>/\&gt;/sg;
+       $value =~ s/\n/<br>\n/sg;
+       print "$label: $value\n";
+   } else {
+       $value =~ s%\n%\n\t\t%sg;
+       print "$label\t$value\n";
+   }
+}
+
 sub prints ($) # print seperator w/ given text
 {
    my ($label) = @_;
    if ($opt_html) {
+       $label =~ s/</\&lt;/sg;
+       $label =~ s/>/\&gt;/sg;
+       $label =~ s/\n/<br>\n/sg;
        print "<tr><td align=center colspan=2><b>$label</b></td></tr>\n";
    } else {
        print "\n---=== $label ===---\n";
@@ -71,74 +115,116 @@ sub printh ($) # print header w/ given text
 {
    my ($label) = @_;
    if ($opt_html) {
-       $label =~ s%\n%<br>%sg;
+       $label =~ s/</\&lt;/sg;
+       $label =~ s/>/\&gt;/sg;
+       $label =~ s/\n/<br>\n/sg;
        print "<h1>$label</h1>\n";
    } else {
 	print "\n$label\n";
    }
 }
 
+sub readspd16 ($$) { # reads 16 bytes from SPD-EEPROM
+	my ($offset, $dimm_i) = @_;
+	if ($use_sysfs) {
+		# Kernel 2.6 with sysfs
+		open (HANDLE, "/sys/bus/i2c/drivers/eeprom/$dimm_i/eeprom")
+			or die "Cannot open /sys/bus/i2c/drivers/eeprom/$dimm_i/eeprom";
+		binmode HANDLE;
+		seek (HANDLE, $offset, 0);
+		read (HANDLE, my $eeprom, 16);
+		close HANDLE;
+		my @bytes = ();
+		for my $i ( 0 .. 15 ) {
+			$_ = ord substr($eeprom, $i, 1);
+			push(@bytes, $_);
+		}
+		return @bytes;
+	} else {
+		# Kernel 2.4 with procfs
+		$offset = sprintf('%02x', $offset);
+		$_ = `cat /proc/sys/dev/sensors/$dimm_i/$offset`;
+		return split(" ");
+	}
+}
+
 for (@ARGV) {
     if (/-h/) {
-	print "Usage: $0 [-f|-b|-h]
-
-  -f, --format            print nice html output
-  -b, --bodyonly          don't printhtml header
-                          (useful for postprocessing the output)
-  -h, --help              display this usage summary
-";
-	exit;
+		print "Usage: $0 [-f|-b|-h]\n\n",
+			"  -f, --format            print nice html output\n",
+			"  -b, --bodyonly          don't print html header\n",
+			"                          (useful for postprocessing the output)\n",
+			"  -c, --checksum          decode completely even if checksum fails\n",
+			"  -h, --help              display this usage summary\n";
+		exit;
     }
     $opt_html = 1 if (/-f/);
     $opt_bodyonly = 1 if (/-b/);
+    $opt_igncheck = 1 if (/-c/);
 }
-$opt_body = $opt_html and not $opt_bodyonly;
+$opt_body = $opt_html && ! $opt_bodyonly;
 
-print "<html><head></head><body>\n" if $opt_body;
+if ($opt_body)
+{
+	print "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 3.2 Final//EN\">\n",
+	      "<html><head>\n",
+		  "\t<meta HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=iso-8859-1\">\n",
+		  "\t<title>PC DIMM Serial Presence Detect Tester/Decoder Output</title>\n",
+		  "</head><body>\n";
+}
 
 printh '
 PC DIMM Serial Presence Detect Tester/Decoder
-Written by Philip Edelbrock.  Copyright 1998, 1999.
-Modified by Christian Zuckschwerdt <zany@triq.net>
-Version 2.6.3
+By Philip Edelbrock, Christian Zuckschwerdt, Burkart Lingner and others
+Version 2.9.2
 ';
 
-print "<table border=1>\n" if $opt_html;
 
-$dimm_count=0;
-$_=`ls /proc/sys/dev/sensors/`;
-@dimm_list=split();
+my $dimm_count=0;
+if ($use_sysfs) { $_=`ls /sys/bus/i2c/drivers/eeprom`; }
+else { $_=`ls /proc/sys/dev/sensors/`; }
+my @dimm_list=split();
 
-for $i ( 0 .. $#dimm_list ) {
+for my $i ( 0 .. $#dimm_list ) {
 	$_=$dimm_list[$i];
-	if (/^eeprom-/) {
-		$dimm_checksum=0;
-		$dimm_count=$dimm_count + 1;
+	if (($use_sysfs && /^\d+-\d+$/)
+	 || (!$use_sysfs && /^eeprom-/)) {
+		my $dimm_checksum=0;
+		$dimm_count += 1;
 		
-		printl "Decoding EEPROM", "/proc/sys/dev/sensors/$dimm_list[$i]";
-		if (/^[^-]+-[^-]+-[^-]+-([^-]+)$/) {
-			$dimm_num=$1 - 49;
+		print "<b><u><br><br>" if $opt_html;
+		printl2 "Decoding EEPROM", ($use_sysfs ?
+			"/sys/bus/i2c/drivers/eeprom/$dimm_list[$i]" :
+			"/proc/sys/dev/sensors/$dimm_list[$i]");
+		print "</u></b>" if $opt_html;
+		print "<table border=1>\n" if $opt_html;
+		if (($use_sysfs && /^[^-]+-([^-]+)$/)
+		 || (!$use_sysfs && /^[^-]+-[^-]+-[^-]+-([^-]+)$/)) {
+			my $dimm_num=$1 - 49;
 			printl "Guessing DIMM is in", "bank $dimm_num";
 		}
 # Decode first 16 bytes
 		prints "The Following is Required Data and is Applicable to all DIMM Types";
 
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/00`;
-		@bytes=split(" ");
-		for $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
+		my @bytes = readspd16(0, $dimm_list[$i]);
+		for my $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
 		
 		printl "# of bytes written to SDRAM EEPROM",$bytes[0];
 
-		$l = "Total number of bytes in EEPROM";
+		my $l = "Total number of bytes in EEPROM";
 		if ($bytes[1] <= 13) {
 			printl $l, 2**$bytes[1];
 		} elsif ($bytes[1] == 0) {
 			printl $l, "RFU"; 
 		} else { printl $l, "ERROR!"; }
 
-		$l = "Fundemental Memory type";
+		$l = "Fundamental Memory type";
 		if ($bytes[2] == 2) { printl $l, "EDO"; }
-		elsif ($bytes[2] == 4) { printl $l, "SDRAM"; }
+		elsif ($bytes[2] == 4) { printl $l, "SDR SDRAM"; }
+		elsif ($bytes[2] == 7) { printl $l, "DDR SDRAM"; }
+		elsif ($bytes[2] == 8) { printl $l, "DDR2 SDRAM"; }
+		elsif ($bytes[2] == 17) { printl $l, "Rambus [UNSUPPORTED]"; }
+		elsif ($bytes[2] == 1) { printl $l, "Direct Rambus [UNSUPPORTED]"; }
 		else { printl $l, "???"; }
 
 		$l = "Number of Row Address Bits (SDRAM only)";
@@ -161,7 +247,7 @@ for $i ( 0 .. $#dimm_list ) {
 
 		$l = "Data Width (SDRAM only)";
 		if ($bytes[7] > 1) { printl $l, "Undefined!" } else {
-			$temp=($bytes[7]*256) + $bytes[6];
+			my $temp=($bytes[7]*256) + $bytes[6];
 			printl $l, $temp; }
 
 		$l = "Module Interface Signal Levels";
@@ -174,9 +260,25 @@ for $i ( 0 .. $#dimm_list ) {
 		else { printl $l, "Undefined!";}
 		
 		$l = "Cycle Time (SDRAM) highest CAS latency";
-		$temp=($bytes[9] >> 4) + ($bytes[9] & 0xf) * 0.1;
+		my $temp=($bytes[9] >> 4) + ($bytes[9] & 0xf) * 0.1;
 		printl $l, "${temp}ns";
 		
+		if (($bytes[2] == 7) || ($bytes[2] == 8)) {
+			my $mul = 2;
+			my $ddr = "DDR";
+			if ($bytes[2] == 8) {
+				$mul = 4;
+				$ddr = "DDR2";
+			} 
+			my $ddrclk = $mul * (1000/$temp);
+			my $tbits = ($bytes[7]*256) + $bytes[6];
+			if (($bytes[11] == 2) ||  ($bytes[11] == 1)) { $tbits = $tbits - 8;}
+			my $pcclk = int ($ddrclk * $tbits / 8);
+			$pcclk = $pcclk - ($pcclk % 100);
+			$ddrclk = int ($ddrclk);
+			printl "Maximum module speed", "$ddr ${ddrclk}MHz (PC${pcclk})";
+		}
+	
 		$l = "Access Time (SDRAM)";
 		$temp=($bytes[10] >> 4) + ($bytes[10] & 0xf) * 0.1;
 		printl $l, "${temp}ns";
@@ -226,9 +328,8 @@ for $i ( 0 .. $#dimm_list ) {
 		prints "The Following Apply to SDRAM DIMMs ONLY";
 		
 # Decode next 16 bytes
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/10`;
-		@bytes=split(" ");
-		for $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j]; }
+		@bytes = readspd16(16, $dimm_list[$i]);
+		for my $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j]; }
 		
 		$l = "Burst lengths supported";
 		$temp="";
@@ -343,7 +444,7 @@ for $i ( 0 .. $#dimm_list ) {
 		
 		prints "The Following are Required (for SDRAMs)";
 		
-		$l = "Minumum Row Precharge Time";
+		$l = "Minimum Row Precharge Time";
 		if ($bytes[11] == 0) { printl $l, "Undefined!"; }
 		else { printl $l, "$bytes[11]nS"; }
 		
@@ -377,9 +478,8 @@ for $i ( 0 .. $#dimm_list ) {
 		
 		
 # Decode next 16 bytes (32-47)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/20`;
-		@bytes=split(" ");
-		for $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
+		@bytes = readspd16(32, $dimm_list[$i]);
+		for my $j ( 0 .. 15 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
 		
 		prints "The Following are Proposed and Apply to SDRAM DIMMs";
 		
@@ -401,23 +501,24 @@ for $i ( 0 .. $#dimm_list ) {
 
 # That's it for the lower part of an SDRAM EEPROM's memory!
 # Decode next 16 bytes (48-63)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/30`;
-		@bytes=split(" ");
-		for $j ( 0 .. 14 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
+		@bytes = readspd16(48, $dimm_list[$i]);
+		for my $j ( 0 .. 14 ) { $dimm_checksum = $dimm_checksum + $bytes[$j];  }
 
 		printl "SPD Revision code ", sprintf("%x", $bytes[14]);
 		$l = "EEPROM Checksum of bytes 0-62";
-		$temp = sprintf("0x%.2X (verses calculated: 0x%.2X)\n",$bytes[15],$dimm_checksum & 255);
-		printl $l, $temp;
+		$dimm_checksum &= 0xff;
+		printl $l, ($bytes[15]==$dimm_checksum?
+			sprintf("OK (0x%.2X)",$bytes[15]):
+			sprintf("Bad (found 0x%.2X, calculated 0x%.2X)\n",$bytes[15],$dimm_checksum));
 
+		if($bytes[15]==$dimm_checksum || $opt_igncheck) {
 # Decode next 16 bytes (64-79)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/40`;
-		@bytes=split(" ");
+		@bytes = readspd16(64, $dimm_list[$i]);
 		
 		$l = "Manufacturer's JEDEC ID Code";
 		$temp = sprintf("0x%.2X%.2X%.2X%.2X%.2X%.2X%.2X%.2X\n",$bytes[0],$bytes[1],$bytes[2],$bytes[3],$bytes[4],$bytes[5],$bytes[6],$bytes[7]);
 		printl $l, $temp;
-		$temp = pack("cccccccc",
+		$temp = pack("C8",
 			$bytes[0],$bytes[1],$bytes[2],$bytes[3],$bytes[4],$bytes[5],$bytes[6],$bytes[7]);
 		printl $l, "(\"$temp\")";
 		
@@ -425,31 +526,29 @@ for $i ( 0 .. $#dimm_list ) {
 		$temp = sprintf("0x%.2X\n",$bytes[8]);
 		printl $l, $temp;
 		
-		$l = "Manufacurer's Part Number:\"";
+		$l = "Manufacurer's Part Number";
 # Decode next 16 bytes (80-95)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/50`;
-		@bytes2=split(" ");
-		$temp = pack("cccccccccccccccccc",$bytes[9],$bytes[10],$bytes[11],$bytes[12],$bytes[13],$bytes[14],$bytes[15],
-			$bytes2[0],$bytes2[1],$bytes2[2],$bytes2[3],$bytes2[4],$bytes2[5],$bytes2[6],$bytes2[7],$bytes2[8],$bytes2[9]);
+		my @bytes2= readspd16(80, $dimm_list[$i]);
+
+		$temp = pack("C18",$bytes[9],$bytes[10],$bytes[11],$bytes[12],$bytes[13],$bytes[14],$bytes[15],
+			$bytes2[0],$bytes2[1],$bytes2[2],$bytes2[3],$bytes2[4],$bytes2[5],$bytes2[6],$bytes2[7],$bytes2[8],$bytes2[9],$bytes2[10]);
 		printl $l, $temp;
 		
 		$l = "Revision Code";
-		$temp = sprintf("0x%.2X%.2X\n",$bytes2[10],$bytes2[11]);
+		$temp = sprintf("0x%.2X%.2X\n",$bytes2[11],$bytes2[12]);
 		printl $l, $temp;
 		
 		$l = "Manufacturing Date";
-		$temp = sprintf("0x%.2X%.2X\n",$bytes2[12],$bytes2[13]);
+		$temp = sprintf("0x%.2X%.2X\n",$bytes2[13],$bytes2[14]);
 		printl $l, $temp;
 		
 		$l = "Assembly Serial Number";
 # Decode next 16 bytes (96-111)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/60`;
-		@bytes=split(" ");
+		@bytes = readspd16(96, $dimm_list[$i]);
 		
 		$temp = sprintf("0x%.2X%.2X%.2X%.2X\n",$bytes2[15],$bytes[0],$bytes[1],$bytes[2]);
 # Decode next 16 bytes (112-127)
-		$_=`cat /proc/sys/dev/sensors/$dimm_list[$i]/70`;
-		@bytes=split(" ");
+		@bytes = readspd16(112, $dimm_list[$i]);
 		
 		$l = "Intel Specification for Frequency";
 		if ($bytes[14] == 102) { printl $l, "66MHz\n"; }
@@ -470,12 +569,13 @@ for $i ( 0 .. $#dimm_list ) {
 		if ($bytes[15] > 175) { $temp .= "Double Sided DIMM\n"; }
 		else { $temp .= "Single Sided DIMM\n";}
 		printl $l, $temp;
+		}
 		
-		
+		print "</table>\n" if $opt_html;
 	}
 }
-printl "Number of SDRAM DIMMs detected and decoded", $dimm_count;
+print '<br><br>' if $opt_html;
+printl2 "Number of SDRAM DIMMs detected and decoded", $dimm_count;
 
-print "</table>\n" if $opt_html;
 print "</body></html>\n" if $opt_body;
 print "\nTry '$0 --format' for html output.\n" unless $opt_html;
