@@ -37,10 +37,13 @@ extern void print_lm78(const sensors_chip_name *name);
 extern void print_sis5595(const sensors_chip_name *name);
 extern void print_via686a(const sensors_chip_name *name);
 extern void print_gl518(const sensors_chip_name *name);
+extern void print_gl520(const sensors_chip_name *name);
 extern void print_lm80(const sensors_chip_name *name);
 extern void print_lm85(const sensors_chip_name *name);
 extern void print_w83781d(const sensors_chip_name *name);
+extern void print_w83792d(const sensors_chip_name *name);
 extern void print_w83l785ts(const sensors_chip_name *name);
+extern void print_w83627ehf(const sensors_chip_name *name);
 extern void print_maxilife(const sensors_chip_name *name);
 extern void print_ddcmon(const sensors_chip_name *name);
 extern void print_eeprom(const sensors_chip_name *name);
@@ -60,10 +63,12 @@ extern void print_vt8231(const sensors_chip_name *name);
 extern void print_bmc(const sensors_chip_name *name);
 extern void print_lm83(const sensors_chip_name *name);
 extern void print_lm90(const sensors_chip_name *name);
+extern void print_lm63(const sensors_chip_name *name);
 extern void print_lm93(const sensors_chip_name *name);
 extern void print_max1619(const sensors_chip_name *name);
 extern void print_xeontemp(const sensors_chip_name *name);
 extern void print_max6650(const sensors_chip_name *name);
 extern void print_adm1031(const sensors_chip_name *name);
+extern void print_smsc47b397(const sensors_chip_name *name);
 
 #endif /* def PROG_SENSORS_CHIPS_H */
